@@ -124,7 +124,7 @@ void do_warn(SV* h, int rc, char* what) {
  **************************************************************************/
 
 int MyConnect(dbh_t *sock, char* host, char* port, char* user,
-	      char* password) {
+	      char* password, char* dbname) {
     int portNr;
 
     if (host && !*host) host = NULL;
@@ -161,15 +161,17 @@ int MyConnect(dbh_t *sock, char* host, char* port, char* user,
 	    mysql_port = oldPort;
 	}
 	return result;
-#else
-#if defined(MYSQL_VERSION_ID)  &&  MYSQL_VERSION_ID >= 032115
+#elif defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32200)
+	return mysql_real_connect(*sock, host, user, password, dbname,
+				  portNr, NULL, 0) ?
+	    TRUE : FALSE;
+#elif defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32115)
 	return mysql_real_connect(*sock, host, user, password, portNr, NULL,
 				  0) ?
 	    TRUE : FALSE;
 #else
 	return mysql_real_connect(*sock, host, user, password, portNr, NULL) ?
 	    TRUE : FALSE;
-#endif
 #endif
     }
 #else
@@ -274,7 +276,12 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
     imp_dbh->svsock = &imp_dbh->mysql;
 #endif
 
-    if (!MyConnect(&imp_dbh->svsock, host, port, user, password)) {
+#if defined(DBD_MYSQL)  &&  (MYSQL_VERSION_ID >= 32200)
+    if (!MyConnect(&imp_dbh->svsock, host, port, user, password, dbname)) {
+        return FALSE;
+    }
+#else
+    if (!MyConnect(&imp_dbh->svsock, host, port, user, password, NULL)) {
         return FALSE;
     }
 
@@ -282,6 +289,8 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
         MyClose(imp_dbh->svsock);
 	return FALSE;
     }
+#endif
+
     return TRUE;
 }
 
